@@ -13,10 +13,14 @@ MULTIUPLOADER_FILES_FOLDER = 'multiuploader'
 
 MULTIUPLOADER_FORMS_SETTINGS = {
     'default': {
-        'FILE_TYPES' : ["txt","zip","jpg","jpeg","flv","png"],
-        'CONTENT_TYPES' : [
+        'FILE_TYPES': ['jpg', 'jpeg', 'png', 'txt', 'zip', 'rar', 'doc', 'docx', 'xls', 'xlsx', 'ppt', 'pptx', 'odt', 'ods', 'odp', 'rtf'],
+        'CONTENT_TYPES': [
                 'image/jpeg',
                 'image/png',
+                'text/plain',
+                'application/zip',
+                'application/x-rar-compressed',
+                'application/octet-stream',
                 'application/msword',
                 'application/vnd.openxmlformats-officedocument.wordprocessingml.document',
                 'application/vnd.ms-excel',
@@ -26,15 +30,15 @@ MULTIUPLOADER_FORMS_SETTINGS = {
                 'application/vnd.oasis.opendocument.text',
                 'application/vnd.oasis.opendocument.spreadsheet',
                 'application/vnd.oasis.opendocument.presentation',
-                'text/plain',
                 'text/rtf',
-                    ],
+        ],
         'MAX_FILE_SIZE': 10485760,
-        'MAX_FILE_NUMBER':5
+        'MAX_FILE_NUMBER': 5,
+        'AUTO_UPLOAD': True
     },
-    'images':{
-        'FILE_TYPES' : ['jpg', 'jpeg', 'png', 'gif', 'svg', 'bmp', 'tiff', 'ico' ],
-        'CONTENT_TYPES' : [
+    'images': {
+        'FILE_TYPES': ['jpg', 'jpeg', 'png', 'gif', 'svg', 'bmp', 'tiff', 'ico'],
+        'CONTENT_TYPES': [
             'image/gif',
             'image/jpeg',
             'image/pjpeg',
@@ -43,13 +47,14 @@ MULTIUPLOADER_FORMS_SETTINGS = {
             'image/tiff',
             'image/vnd.microsoft.icon',
             'image/vnd.wap.wbmp',
-            ],
+        ],
         'MAX_FILE_SIZE': 10485760,
-        'MAX_FILE_NUMBER':5
+        'MAX_FILE_NUMBER': 5,
+        'AUTO_UPLOAD': True
     },
-    'video':{
-        'FILE_TYPES' : ['flv', 'mpg', 'mpeg', 'mp4' ,'avi', 'mkv', 'ogg', 'wmv', 'mov', 'webm' ],
-        'CONTENT_TYPES' : [
+    'video': {
+        'FILE_TYPES': ['flv', 'mpg', 'mpeg', 'mp4' ,'avi', 'mkv', 'ogg', 'wmv', 'mov', 'webm'],
+        'CONTENT_TYPES': [
             'video/mpeg',
             'video/mp4',
             'video/ogg',
@@ -57,13 +62,14 @@ MULTIUPLOADER_FORMS_SETTINGS = {
             'video/webm',
             'video/x-ms-wmv',
             'video/x-flv',
-            ],
+        ],
         'MAX_FILE_SIZE': 10485760,
-        'MAX_FILE_NUMBER':5
+        'MAX_FILE_NUMBER': 5,
+        'AUTO_UPLOAD': True
     },
-    'audio':{
-        'FILE_TYPES' : ['mp3', 'mp4', 'ogg', 'wma', 'wax', 'wav', 'webm' ],
-        'CONTENT_TYPES' : [
+    'audio': {
+        'FILE_TYPES': ['mp3', 'mp4', 'ogg', 'wma', 'wax', 'wav', 'webm'],
+        'CONTENT_TYPES': [
             'audio/basic',
             'audio/L24',
             'audio/mp4',
@@ -75,8 +81,9 @@ MULTIUPLOADER_FORMS_SETTINGS = {
             'audio/vnd.rn-realaudio',
             'audio/vnd.wave',
             'audio/webm'
-            ],
+        ],
         'MAX_FILE_SIZE': 10485760,
-        'MAX_FILE_NUMBER':5
+        'MAX_FILE_NUMBER': 5,
+        'AUTO_UPLOAD': True
     },
 }
\ No newline at end of file
